@@ -4,7 +4,6 @@ context("Test that get_power queries the server and returns the proper
         requested data")
 test_that("get_power returns daily point AG data", {
   skip_on_cran()
-  vcr::use_cassette(name = "get_single_point_daily", {
     power_query <- get_power(
       community = "AG",
       lonlat = c(-179.5, -89.5),
@@ -33,12 +32,10 @@ test_that("get_power returns daily point AG data", {
     expect_equal(power_query$RH2M, 73.92)
     expect_equal(power_query$WS10M, 2.14)
     rm(power_query)
-  })
 })
 
 test_that("get_power returns daily regional AG data", {
   skip_on_cran()
-  vcr::use_cassette(name = "get_regional_daily", {
     power_query <- get_power(
       community = "AG",
       lonlat = c(112.5, -55.5, 115.5, -50.5),
@@ -76,12 +73,10 @@ test_that("get_power returns daily regional AG data", {
     expect_equal(power_query$DOY[1], 1)
     expect_equal(power_query$T2M[1], 3.28)
     rm(power_query)
-  })
 })
 
 test_that("get_power returns global AG data for climatology", {
   skip_on_cran()
-  vcr::use_cassette(name = "get_climatology", {
     power_query <- get_power(
       community = "AG",
       pars = "T2M",
@@ -116,7 +111,6 @@ test_that("get_power returns global AG data for climatology", {
       )
     )
     rm(power_query)
-  })
 })
 
 test_that("get_power() stops if `temporal_average` not valid", {
